==> mingw-w64-clang-aarch64-qgis-3.34.3-1-any.pkg.tar.zst: clangarm64/include/qgsconfig.h <==

// QGSCONFIG.H

#ifndef QGSCONFIG_H
#define QGSCONFIG_H

// Version must be specified according to
// <int>.<int>.<int>-<any text>.
// or else upgrading old project file will not work
// reliably.
// TODO QGIS 4: remove in favor of _QGIS_VERSION
#define VERSION "3.34.3-Prizren"
#define _QGIS_VERSION "3.34.3-Prizren"

//used in vim src/core/qgis.cpp
//The way below should work but it resolves to a number like 0110 which the compiler treats as octal I think
//because debuggin it out shows the decimal number 72 which results in incorrect version status.
//As a short term fix I (Tim) am defining the version in top level cmake. It would be good to
//reinstate this more generic approach below at some point though
//#define VERSION_INT 3343
// TODO QGIS 4: Remove in favor of _QGIS_VERSION_INT
#define VERSION_INT 33403
#define _QGIS_VERSION_INT 33403
#define ABISYM(x) x ## 33403
//used in main.cpp and anywhere else where the release name is needed
#define RELEASE_NAME "Prizren"

#define QGIS_PLUGIN_SUBDIR "lib/qgis/plugins"
#define QGIS_DATA_SUBDIR "share"
#define QGIS_LIBEXEC_SUBDIR "bin"
#define QGIS_LIB_SUBDIR "lib"
#define QGIS_QML_SUBDIR "qml"
#define CMAKE_INSTALL_PREFIX "/clangarm64"
#define CMAKE_SOURCE_DIR "C:/M/B/src/qgis-3.34.3"

#define QGIS_SERVER_MODULE_SUBDIR "server"

#if !defined(QSCINTILLA_VERSION_STR)
#define QSCINTILLA_VERSION_STR "2.14.1"
#endif

#if defined( __APPLE__ )
//used by Mac to find system or bundle resources relative to amount of bundling
#define QGIS_MACAPP_BUNDLE 
#endif

#define QT_PLUGINS_DIR "share/qt5/plugins"

#define PYTHON_VERSION "3.11.7"
#define PYTHON_VERSION_MAJOR "3"
#define PYTHON_VERSION_MINOR "11"
#define PYTHON_VERSION_PATCH "7"

#define PROJ_VERSION_MAJOR 9
#define PROJ_VERSION_MINOR 3
#define PROJ_VERSION_PATCH 1

/* #undef USING_NMAKE */

#define USING_NINJA

#define HAVE_GUI

#define HAVE_SPATIALITE

#define HAVE_POSTGRESQL

/* #undef HAVE_ORACLE */

/* #undef HAVE_HANA */

/* #undef SERVER_SKIP_ECW */

/* #undef HAVE_SERVER_PYTHON_PLUGINS */

#define HAVE_OAUTH2_PLUGIN

#define HAVE_OPENCL
#define OPENCL_USE_NEW_HEADER

/* #undef ENABLE_MODELTEST */

#define HAVE_3D

#define HAVE_GSL

#define HAVE_GEOREFERENCER

/* #undef USE_THREAD_LOCAL */

/* #undef QGISDEBUG */

/* #undef AGGRESSIVE_SAFE_MODE */

/* #undef HAVE_QUICK */

#define HAVE_QTSERIALPORT

/* #undef HAVE_QTGAMEPAD */

/* #undef HAVE_STATIC_PROVIDERS */

#define HAVE_EPT

#define HAVE_COPC

/* #undef HAVE_PDAL_QGIS */
#define PDAL_VERSION ""
#define PDAL_VERSION_MAJOR_INT 
#define PDAL_VERSION_MINOR_INT 
#define PDAL_VERSION_MAJOR ""
#define PDAL_VERSION_MINOR ""
#define PDAL_VERSION_MICRO ""

#define HAVE_DRACO

/* #undef ENABLE_TESTS */

#define HAS_KDE_QT5_PDF_TRANSFORM_FIX
#define HAS_KDE_QT5_SMALL_CAPS_FIX
#define HAS_KDE_QT5_FONT_STRETCH_FIX

/* #undef HAVE_CRASH_HANDLER */

#endif

==> mingw-w64-clang-aarch64-qgis-3.36.0-1-any.pkg.tar.zst: clangarm64/include/qgsconfig.h <==

// QGSCONFIG.H

#ifndef QGSCONFIG_H
#define QGSCONFIG_H

// Version must be specified according to
// <int>.<int>.<int>-<any text>.
// or else upgrading old project file will not work
// reliably.
// TODO QGIS 4: remove in favor of _QGIS_VERSION
#define VERSION "3.36.0-Maidenhead"
#define _QGIS_VERSION "3.36.0-Maidenhead"

//used in vim src/core/qgis.cpp
//The way below should work but it resolves to a number like 0110 which the compiler treats as octal I think
//because debuggin it out shows the decimal number 72 which results in incorrect version status.
//As a short term fix I (Tim) am defining the version in top level cmake. It would be good to
//reinstate this more generic approach below at some point though
//#define VERSION_INT 3360
// TODO QGIS 4: Remove in favor of _QGIS_VERSION_INT
#define VERSION_INT 33600
#define _QGIS_VERSION_INT 33600
#define ABISYM(x) x ## 33600
//used in main.cpp and anywhere else where the release name is needed
#define RELEASE_NAME "Maidenhead"

#define QGIS_PLUGIN_SUBDIR "lib/qgis/plugins"
#define QGIS_DATA_SUBDIR "share"
#define QGIS_LIBEXEC_SUBDIR "bin"
#define QGIS_LIB_SUBDIR "lib"
#define QGIS_QML_SUBDIR "qml"
#define CMAKE_INSTALL_PREFIX "/clangarm64"
#define CMAKE_SOURCE_DIR "C:/M/B/src/qgis-3.36.0"

#define QGIS_SERVER_MODULE_SUBDIR "server"

#if !defined(QSCINTILLA_VERSION_STR)
#define QSCINTILLA_VERSION_STR "2.14.1"
#endif

#if defined( __APPLE__ )
//used by Mac to find system or bundle resources relative to amount of bundling
#define QGIS_MACAPP_BUNDLE 
#endif

#define QT_PLUGINS_DIR "share/qt5/plugins"

#define PYTHON_VERSION "3.11.8"
#define PYTHON_VERSION_MAJOR "3"
#define PYTHON_VERSION_MINOR "11"
#define PYTHON_VERSION_PATCH "8"

#define PROJ_VERSION_MAJOR 9
#define PROJ_VERSION_MINOR 3
#define PROJ_VERSION_PATCH 1

/* #undef USING_NMAKE */

#define USING_NINJA

#define HAVE_GUI

#define HAVE_SPATIALITE

#define HAVE_POSTGRESQL

/* #undef HAVE_ORACLE */

/* #undef HAVE_HANA */

/* #undef SERVER_SKIP_ECW */

/* #undef HAVE_SERVER_PYTHON_PLUGINS */

#define HAVE_OAUTH2_PLUGIN

#define HAVE_OPENCL
#define OPENCL_USE_NEW_HEADER

/* #undef ENABLE_MODELTEST */

#define HAVE_3D

#define HAVE_GSL

#define HAVE_GEOREFERENCER

/* #undef USE_THREAD_LOCAL */

/* #undef QGISDEBUG */

/* #undef AGGRESSIVE_SAFE_MODE */

/* #undef HAVE_QUICK */

#define HAVE_QTSERIALPORT

/* #undef HAVE_QTGAMEPAD */

#define HAVE_QTPRINTER

/* #undef HAVE_STATIC_PROVIDERS */

#define HAVE_EPT

#define HAVE_COPC

/* #undef HAVE_PDAL_QGIS */
#define PDAL_VERSION ""
#define PDAL_VERSION_MAJOR_INT 
#define PDAL_VERSION_MINOR_INT 
#define PDAL_VERSION_MAJOR ""
#define PDAL_VERSION_MINOR ""
#define PDAL_VERSION_MICRO ""

#define HAVE_DRACO

/* #undef ENABLE_TESTS */

#define HAS_KDE_QT5_PDF_TRANSFORM_FIX
#define HAS_KDE_QT5_SMALL_CAPS_FIX
#define HAS_KDE_QT5_FONT_STRETCH_FIX

/* #undef HAVE_PDF4QT */

/* #undef HAVE_CRASH_HANDLER */

/* #undef HAVE_WEBENGINE */

#endif
